@@ -6,11 +6,12 @@ in the source distribution for its full text.
 */
 
 #include "RichString.h"
+#include "XAlloc.h"
 
 #include <stdlib.h>
 #include <string.h>
 
-#define RICHSTRING_MAXLEN 300
+#define RICHSTRING_MAXLEN 350
 
 /*{
 #include "config.h"
@@ -29,18 +30,22 @@ in the source distribution for its full text.
 #include <curses.h>
 #endif
 
+#ifdef HAVE_LIBNCURSESW
+#include <wctype.h>
+#endif
+
 #define RichString_size(this) ((this)->chlen)
 #define RichString_sizeVal(this) ((this).chlen)
 
-#define RichString_begin(this) RichString (this); (this).chlen = 0; (this).chptr = (this).chstr;
-#define RichString_beginAllocated(this) (this).chlen = 0; (this).chptr = (this).chstr;
+#define RichString_begin(this) RichString (this); memset(&this, 0, sizeof(RichString)); (this).chptr = (this).chstr;
+#define RichString_beginAllocated(this) memset(&this, 0, sizeof(RichString)); (this).chptr = (this).chstr;
 #define RichString_end(this) RichString_prune(&(this));
 
 #ifdef HAVE_LIBNCURSESW
 #define RichString_printVal(this, y, x) mvadd_wchstr(y, x, (this).chptr)
 #define RichString_printoffnVal(this, y, x, off, n) mvadd_wchnstr(y, x, (this).chptr + off, n)
 #define RichString_getCharVal(this, i) ((this).chptr[i].chars[0] & 255)
-#define RichString_setChar(this, at, ch) do{ (this)->chptr[(at)].chars[0] = ch; } while(0)
+#define RichString_setChar(this, at, ch) do{ (this)->chptr[(at)] = (CharType) { .chars = { ch, 0 } }; } while(0)
 #define CharType cchar_t
 #else
 #define RichString_printVal(this, y, x) mvaddchstr(y, x, (this).chptr)
@@ -52,52 +57,48 @@ in the source distribution for its full text.
 
 typedef struct RichString_ {
    int chlen;
-   CharType chstr[RICHSTRING_MAXLEN+1];
    CharType* chptr;
+   CharType chstr[RICHSTRING_MAXLEN+1];
 } RichString;
 
 }*/
 
-#ifndef MIN
-#define MIN(a,b) ((a)<(b)?(a):(b))
-#endif
-
 #define charBytes(n) (sizeof(CharType) * (n)) 
 
-static inline void RichString_setLen(RichString* this, int len) {
+static void RichString_extendLen(RichString* this, int len) {
    if (this->chlen <= RICHSTRING_MAXLEN) {
       if (len > RICHSTRING_MAXLEN) {
-         this->chptr = malloc(charBytes(len+1));
-         memcpy(this->chptr, this->chstr, charBytes(this->chlen+1));
+         this->chptr = xMalloc(charBytes(len + 1));
+         memcpy(this->chptr, this->chstr, charBytes(this->chlen));
       }
    } else {
       if (len <= RICHSTRING_MAXLEN) {
-         memcpy(this->chstr, this->chptr, charBytes(this->chlen));
+         memcpy(this->chstr, this->chptr, charBytes(len));
          free(this->chptr);
          this->chptr = this->chstr;
       } else {
-         this->chptr = realloc(this->chptr, charBytes(len+1));
+         this->chptr = xRealloc(this->chptr, charBytes(len + 1));
       }
    }
+
    RichString_setChar(this, len, 0);
    this->chlen = len;
 }
 
+#define RichString_setLen(this, len) do{ if(len < RICHSTRING_MAXLEN && this->chlen < RICHSTRING_MAXLEN) { RichString_setChar(this,len,0); this->chlen=len; } else RichString_extendLen(this,len); }while(0)
+
 #ifdef HAVE_LIBNCURSESW
 
 static inline void RichString_writeFrom(RichString* this, int attrs, const char* data_c, int from, int len) {
    wchar_t data[len+1];
    len = mbstowcs(data, data_c, len);
-   if (len<0)
+   if (len < 0)
       return;
    int newLen = from + len;
    RichString_setLen(this, newLen);
-   memset(&this->chptr[from], 0, sizeof(CharType) * (newLen - from));
    for (int i = from, j = 0; i < newLen; i++, j++) {
-      this->chptr[i].chars[0] = data[j];
-      this->chptr[i].attr = attrs;
+      this->chptr[i] = (CharType) { .attr = attrs & 0xffffff, .chars = { (iswprint(data[j]) ? data[j] : '?') } };
    }
-   this->chptr[newLen].chars[0] = 0;
 }
 
 inline void RichString_setAttrn(RichString* this, int attrs, int start, int finish) {
@@ -125,7 +126,7 @@ static inline void RichString_writeFrom(RichString* this, int attrs, const char*
    int newLen = from + len;
    RichString_setLen(this, newLen);
    for (int i = from, j = 0; i < newLen; i++, j++)
-      this->chptr[i] = (isprint(data_c[j]) ? data_c[j] : '?') | attrs;
+      this->chptr[i] = (data_c[j] >= 32 ? data_c[j] : '?') | attrs;
    this->chptr[newLen] = 0;
 }
 
@@ -152,9 +153,8 @@ int RichString_findChar(RichString* this, char c, int start) {
 void RichString_prune(RichString* this) {
    if (this->chlen > RICHSTRING_MAXLEN)
       free(this->chptr);
+   memset(this, 0, sizeof(RichString));
    this->chptr = this->chstr;
-   this->chlen = 0;
-   RichString_setChar(this, 0, 0);
 }
 
 void RichString_setAttr(RichString* this, int attrs) {
